aboutsummaryrefslogtreecommitdiffstats
path: root/os/ports/GCC/SIMIA32
diff options
context:
space:
mode:
Diffstat (limited to 'os/ports/GCC/SIMIA32')
-rw-r--r--os/ports/GCC/SIMIA32/chcore.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/os/ports/GCC/SIMIA32/chcore.h b/os/ports/GCC/SIMIA32/chcore.h
index a0e26bf29..114e9ef43 100644
--- a/os/ports/GCC/SIMIA32/chcore.h
+++ b/os/ports/GCC/SIMIA32/chcore.h
@@ -36,9 +36,11 @@
#define CH_ARCHITECTURE_NAME "x86 Simulator"
/**
* 32 bit stack alignment.
*/
-typedef uint32_t stkalign_t;
+typedef struct {
+ uint8_t a[16];
+} stkalign_t __attribute__((aligned(16)));
/**
* Generic x86 register.
@@ -36,9 +36,11 @@
#define CH_ARCHITECTURE_NAME "x86 Simulator"
/**
- * 32 bit stack alignment.
+ * 16 bytes stack alignment.
*/